docs.rs failed to build j2k-transcode-cuda-0.6.2
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
j2k-transcode-cuda-0.6.1
j2k-transcode-cuda
CUDA acceleration adapter for J2K JPEG-to-J2K/HTJ2K transcode stages.
This crate accelerates supported transform and code-block preparation stages.
It does not replace the transcode API in j2k-transcode.